<?php namespace EscapeWork\Manager\Calendars\Controllers;

use EscapeWork\Manager\Controllers\ManagerController;
use EscapeWork\Manager\Calendars\Repositories\CalendarRepository;
use EscapeWork\Manager\Calendars\Repositories\CalendarDayRepository;
use View;
use Input;
use Redirect;
use Response;
use Request;
use Config;
use Msg;

class CalendarsController extends ManagerController
{

    public function __construct(CalendarRepository $Calendar, CalendarDayRepository $CalendarDay)
    {
        $this->calendar     = $Calendar;
        $this->calendarDay  = $CalendarDay;

        $this->enableDefaultFilters('calendars');
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index()
    {
        $view = View::make(Config::get('manager-calendars::views.calendars.index'));

        $view->ordem = 'desc';
        $view->icon = null;
        $view->column = null;

        $query = $this->calendar;

        if (Input::has('title')) {
            $query = $query->where('title', 'like', '%'.Input::get('title').'%');
        }

        if (Input::has('col') && Input::has('ord')) {

            $view->column = Input::get('col');

            if (Input::get('ord') == 'desc')  {
                $view->ordem = 'asc';
                $view->icon = 'icon-chevron-up';
            }

            if (Input::get('ord') == 'asc') {
                $view->ordem = 'desc';
                $view->icon = 'icon-chevron-down';
            }

            $query = $query->orderBy('calendars.'.Input::get('col'), Input::get('ord'));
        }

        $view->calendars = $query->orderBy('created_at', 'desc')->paginate(20);

        return $view;
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        $view = View::make(Config::get('manager-calendars::views.calendars.form'));

        $this->calendar->fill(Input::old());

        $view->calendar     = $this->calendar;
        $view->calendarDay  = $this->calendarDay;
        $view->edit         = false;

        return $view;
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store()
    {
        $this->calendar->fill(Input::except('date'));

        if (! $this->calendar->validate()) {
            return Redirect::route('manager.calendarios.create')
                        ->withInput()
                        ->with('errors', Calendar::$messages);
        }

        $this->calendar->save();

        $this->calendarDay->calendar_id = $this->calendar->id;
        $this->calendarDay->insertFromArray(Input::get('date'));

        return Redirect::route('manager.calendarios.index')->with('message', 'O evento <strong>' . $this->calendar->title . '</strong> foi inserido com sucesso!');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @return Response
     */
    public function edit($id)
    {
        if (! $this->calendar = $this->calendar->find($id)) {
            return Redirect::route('manager.calendarios.index')
                    ->with('error', 'Evento não encontrado');
        }

        Msg::setInfo('Editando o evento <strong>' . $this->calendar->title . '</strong>');

        $view                = View::make(Config::get('manager-calendars::views.calendars.form'));
        $view->calendar      = $this->calendar;
        $view->calendarDays  = $this->calendarDay->where('calendar_days.calendar_id', $id)->get();
        $view->edit          = true;

        return $view;
    }

    /**
     * Salvando no banco de dados
     */
    public function update($id)
    {
        if (! $this->calendar = $this->calendar->find($id)) {
            return Redirect::route('manager.calendarios.index')
                    ->with('error', 'Evento não encontrado');
        }

        $fields = Input::except('_method', 'date');

        $fields = $this->calendar->fill($fields);

        if ( $this->calendar->validate() === false) {
            return Redirect::route('manager.calendarios.edit', array($this->calendar->id))
                    ->withInput()
                    ->with('errors', Calendar::$messages);
        }

        $this->calendar->save();

        # salvando as datas
        $this->calendarDay->calendar_id = $this->calendar->id;
        $this->calendarDay->deleteAllFromEdition();
        $this->calendarDay->insertFromArray(Input::get('date'));

        return Redirect::to('manager/calendarios')
                ->with('message', 'A edição <strong>'.$this->calendar->title.'</strong> foi editada com sucesso!');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @return Response
     */
    public function destroy($id)
    {
        if (! $this->calendar = $this->calendar->find($id)) {
            return Redirect::route('manager.calendarios.index')
                    ->with('error', 'Evento não encontrado');
        }

        $this->calendar->destroy($id);

        return Redirect::route('manager.calendarios.index')
                ->with('message', 'O evento <strong>'.$this->calendar->title.'</strong> foi excluído com sucesso!');
    }

    /**
    * Atualizando se o evento está ativo ou não
    */
    public function updateActive($id)
    {
        if (! $this->calendar = $this->calendar->find($id)) {
            return Response::json(array(
                'error' => 'Evento não encontrada'
            ));
        }

        $this->calendar->active = Input::get('active');
        $this->calendar->save();

        return Response::json(array(
            'message' => 'O evento foi atualizado com sucesso'
        ));
    }

    /**
    * Atualizando se o evento é destaque ou não
    */
    public function updateFeatured($id)
    {
        if (! $this->calendar = $this->calendar->find($id)) {
            return Response::json(array(
                'error' => 'Evento não encontrado'
            ));
        }

        $this->calendar->featured = Input::get('featured');
        $this->calendar->save();

        return Response::json(array(
            'message' => 'O evento foi atualizado com sucesso'
        ));
    }
}
